;;; guix-autoloads.el --- automatically extracted autoloads
;;
;;; Code:


;;;### (autoloads nil "guix" "guix.el" (22073 56029 825740 602000))
;;; Generated autoloads from guix.el

(autoload 'guix-search-by-name "guix" "\
Search for Guix packages by NAME.
NAME is a string with name specification.  It may optionally contain
a version number.  Examples: \"guile\", \"guile-2.0.11\".

If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn NAME &optional PROFILE)" t nil)

(autoload 'guix-search-by-regexp "guix" "\
Search for Guix packages by REGEXP.
PARAMS are package parameters that should be searched.
If PARAMS are not specified, use `guix-search-params'.

If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn REGEXP &optional PARAMS PROFILE)" t nil)

(autoload 'guix-installed-packages "guix" "\
Display information about installed Guix packages.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn &optional PROFILE)" t nil)

(autoload 'guix-obsolete-packages "guix" "\
Display information about obsolete Guix packages.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn &optional PROFILE)" t nil)

(autoload 'guix-all-available-packages "guix" "\
Display information about all available Guix packages.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn &optional PROFILE)" t nil)

(autoload 'guix-newest-available-packages "guix" "\
Display information about the newest available Guix packages.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn &optional PROFILE)" t nil)

(autoload 'guix-generations "guix" "\
Display information about all generations.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn &optional PROFILE)" t nil)

(autoload 'guix-last-generations "guix" "\
Display information about last NUMBER generations.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn NUMBER &optional PROFILE)" t nil)

(autoload 'guix-generations-by-time "guix" "\
Display information about generations created between FROM and TO.
FROM and TO should be time values.
If PROFILE is nil, use `guix-current-profile'.
Interactively with prefix, prompt for PROFILE.

\(fn FROM TO &optional PROFILE)" t nil)

(autoload 'guix-edit "guix" "\
Edit (go to location of) package with ID-OR-NAME.

\(fn ID-OR-NAME)" t nil)

;;;***

;;;### (autoloads nil "guix-base" "guix-base.el" (22073 56029 825740
;;;;;;  602000))
;;; Generated autoloads from guix-base.el

(autoload 'guix-apply-manifest "guix-base" "\
Apply manifest from FILE to PROFILE.
This function has the same meaning as 'guix package --manifest' command.
See Info node `(guix) Invoking guix package' for details.

Interactively, use the current profile and prompt for manifest
FILE.  With a prefix argument, also prompt for PROFILE.

\(fn PROFILE FILE &optional OPERATION-BUFFER)" t nil)

(autoload 'guix-pull "guix-base" "\
Run Guix pull operation.
If VERBOSE is non-nil (with prefix argument), produce verbose output.

\(fn &optional VERBOSE)" t nil)

;;;***

;;;### (autoloads nil "guix-build-log" "guix-build-log.el" (22073
;;;;;;  56029 825740 602000))
;;; Generated autoloads from guix-build-log.el

(autoload 'guix-build-log-mode "guix-build-log" "\
Major mode for viewing Guix build logs.

\\{guix-build-log-mode-map}

\(fn)" t nil)

(autoload 'guix-build-log-minor-mode "guix-build-log" "\
Toggle Guix Build Log minor mode.

With a prefix argument ARG, enable Guix Build Log minor mode if
ARG is positive, and disable it otherwise.  If called from Lisp,
enable the mode if ARG is omitted or nil.

When Guix Build Log minor mode is enabled, it highlights build
log in the current buffer.  This mode can be enabled
programmatically using hooks:

  (add-hook 'shell-mode-hook 'guix-build-log-minor-mode)

\\{guix-build-log-minor-mode-map}

\(fn &optional ARG)" t nil)

(autoload 'guix-build-log-minor-mode-activate-maybe "guix-build-log" "\
Activate `guix-build-log-minor-mode' depending on
`guix-build-log-minor-mode-activate' variable.

\(fn)" nil nil)

(add-to-list 'auto-mode-alist (cons (rx "/guix/drvs/" (= 2 alnum) "/" (= 30 alnum) "-" (+ (any alnum "-+.")) ".drv" string-end) 'guix-build-log-mode))

;;;***

;;;### (autoloads nil "guix-command" "guix-command.el" (22073 56029
;;;;;;  825740 602000))
;;; Generated autoloads from guix-command.el
 (autoload 'guix "guix-command" "Popup window for 'guix'." t)

;;;***

;;;### (autoloads nil "guix-devel" "guix-devel.el" (22073 56029 825740
;;;;;;  602000))
;;; Generated autoloads from guix-devel.el

(autoload 'guix-devel-mode "guix-devel" "\
Minor mode for `scheme-mode' buffers.

With a prefix argument ARG, enable the mode if ARG is positive,
and disable it otherwise.  If called from Lisp, enable the mode
if ARG is omitted or nil.

When Guix Devel mode is enabled, it provides the following key
bindings:

\\{guix-devel-mode-map}

\(fn &optional ARG)" t nil)

(autoload 'guix-devel-activate-mode-maybe "guix-devel" "\
Activate `guix-devel-mode' depending on
`guix-devel-activate-mode' variable.

\(fn)" nil nil)

;;;***

;;;### (autoloads nil "guix-emacs" "guix-emacs.el" (21934 40677 836015
;;;;;;  392000))
;;; Generated autoloads from guix-emacs.el

(autoload 'guix-emacs-load-autoloads "guix-emacs" "\
Load autoloads for Emacs packages installed in a user profile.
Add autoloads directories to `load-path'.
If ALL is nil, activate only those packages that were installed
after the last activation, otherwise activate all Emacs packages
installed in `guix-user-profile'.

\(fn &optional ALL)" t nil)

;;;***

;;;### (autoloads nil "guix-pcomplete" "guix-pcomplete.el" (22073
;;;;;;  56029 825740 602000))
;;; Generated autoloads from guix-pcomplete.el

(autoload 'pcomplete/guix "guix-pcomplete" "\
Completion for `guix'.

\(fn)" nil nil)

;;;***

;;;### (autoloads nil "guix-prettify" "guix-prettify.el" (22073 56029
;;;;;;  825740 602000))
;;; Generated autoloads from guix-prettify.el

(autoload 'guix-prettify-mode "guix-prettify" "\
Toggle Guix Prettify mode.

With a prefix argument ARG, enable Guix Prettify mode if ARG is
positive, and disable it otherwise.  If called from Lisp, enable
the mode if ARG is omitted or nil.

When Guix Prettify mode is enabled, hash-parts of the Guix store
file names (see `guix-prettify-regexp') are prettified,
i.e. displayed as `guix-prettify-char' character.  This mode can
be enabled programmatically using hooks:

  (add-hook 'shell-mode-hook 'guix-prettify-mode)

It is possible to enable the mode in any buffer, however not any
buffer's highlighting may survive after adding new elements to
`font-lock-keywords' (see `guix-prettify-special-modes' for
details).

Also you can use `global-guix-prettify-mode' to enable Guix
Prettify mode for all modes that support font-locking.

\(fn &optional ARG)" t nil)

(defvar global-guix-prettify-mode nil "\
Non-nil if Global-Guix-Prettify mode is enabled.
See the command `global-guix-prettify-mode' for a description of this minor mode.
Setting this variable directly does not take effect;
either customize it (see the info node `Easy Customization')
or call the function `global-guix-prettify-mode'.")

(custom-autoload 'global-guix-prettify-mode "guix-prettify" nil)

(autoload 'global-guix-prettify-mode "guix-prettify" "\
Toggle Guix-Prettify mode in all buffers.
With prefix ARG, enable Global-Guix-Prettify mode if ARG is positive;
otherwise, disable it.  If called from Lisp, enable the mode if
ARG is omitted or nil.

Guix-Prettify mode is enabled in all buffers where
`guix-prettify-turn-on' would do it.
See `guix-prettify-mode' for more information on Guix-Prettify mode.

\(fn &optional ARG)" t nil)

(defalias 'guix-prettify-global-mode 'global-guix-prettify-mode)

;;;***

;;;### (autoloads nil nil ("guix-backend.el" "guix-config.el" "guix-external.el"
;;;;;;  "guix-geiser.el" "guix-guile.el" "guix-help-vars.el" "guix-history.el"
;;;;;;  "guix-info.el" "guix-init.el" "guix-list.el" "guix-messages.el"
;;;;;;  "guix-popup.el" "guix-profiles.el" "guix-read.el" "guix-utils.el")
;;;;;;  (22073 56147 342847 820000))

;;;***

(provide 'guix-autoloads)
;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8
;; End:
;;; guix-autoloads.el ends here
